summaryrefslogtreecommitdiffstats
path: root/src/tools/appman/appman.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/tools/appman/appman.cpp')
-rw-r--r--src/tools/appman/appman.cpp7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/tools/appman/appman.cpp b/src/tools/appman/appman.cpp
index 1a1eb28e..83554ebe 100644
--- a/src/tools/appman/appman.cpp
+++ b/src/tools/appman/appman.cpp
@@ -1,9 +1,10 @@
/****************************************************************************
**
+** Copyright (C) 2019 Luxoft Sweden AB
** Copyright (C) 2018 Pelagicore AG
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Pelagicore Application Manager.
**
** $QT_BEGIN_LICENSE:LGPL-QTAS$
** Commercial License Usage
@@ -68,8 +69,8 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
#else
QCoreApplication::setApplicationName(qSL("ApplicationManager"));
#endif
- QCoreApplication::setOrganizationName(qSL("Pelagicore AG"));
- QCoreApplication::setOrganizationDomain(qSL("pelagicore.com"));
+ QCoreApplication::setOrganizationName(qSL("Luxoft Sweden AB"));
+ QCoreApplication::setOrganizationDomain(qSL("luxoft.com"));
QCoreApplication::setApplicationVersion(qSL(AM_VERSION));
Logging::initialize(argc, argv);
@@ -1,9 +1,10 @@
** Contact: https://www.qt.io/licensing/
**
-** This file is part of the Pelagicore Application Manager.
+** This file is part of the Luxoft Application Manager.
**
** $QT_BEGIN_LICENSE:LGPL-QTAS$